@@ -1,10 +1,12 @@
 import sys
 import inspect
+from json import dumps
 from operator import attrgetter
 from functools import wraps, partial
 from itertools import cycle
+import warnings
 
-from fresco import GET, POST, PUT
+from fresco import GET, POST, PUT, Response
 from fresco.exceptions import BadRequest
 
 
@@ -32,11 +34,52 @@ def onerror(exceptions, handler):
     return decorator
 
 
+def json_response(data=None, indent=None, separators=(',', ':'), **kwargs):
+    """
+    JSON encode the given data and return a response object with the json mime
+    type.
+
+    Can be used as a function decorator, in which case it will wrap the
+    function's return value as a json response.
+
+    :param data: The data to json encode.
+                 If left as None, ``json_response``
+                 will act as a function decorator.
+    :param indent: The indent level. Defaults to ``None`` (no pretty printing)
+    :param separators: Defaults to ``(',', ':')`` for the most compact JSON
+                       representation
+    :param kwargs: Other keyword arguments are passed to ``json.dumps``. These
+                   may be used to change encoding paramters, for example
+                   overriding the default ``JSONEncoder`` class.
+
+
+    """
+    if data is None:
+        def json_response_decorator(func):
+            @wraps(func)
+            def json_response_decorated(*fa, **fkw):
+                return json_response(
+                    func(*fa, **fkw), indent, separators, **kwargs)
+            return json_response_decorated
+        return json_response_decorator
+
+    if isinstance(data, Response):
+        return data
+
+    return Response(
+            content_type='application/json',
+            content=[dumps(
+                data, indent=indent, separators=separators, **kwargs)])
+
+
 def extract_requestargs(requesttype, **argspec):
     """
     Decorator mapping request querystring/post data to function arguments.
 
     """
+    warnings.warn("extract_requestargs is deprecated. "
+                  "Please see fresco.routeargs for alternatives",
+                  DeprecationWarning, stacklevel=2)
     request_attr = {
         GET: attrgetter('query'),
         POST: attrgetter('form'),
@@ -92,7 +135,7 @@ def extract_requestargs(requesttype, **argspec):
                             value = defaults[name]
                         else:
                             raise exception(
-                                "Could not convert parameter %r to "\
+                                "Could not convert parameter %r to "
                                 " requested type (%s)" % (name, e.args[0])
                             )
 
@@ -137,11 +180,11 @@ extract_getargs.__doc__ = """\
     is given in the function signature), or a ValueError is thrown during type
     conversion an appropriate error will be raised::
 
-        >>> print TestAgent(my_app.wsgi_app).get('/') #doctest: +ELLIPSIS
+        >>> TestAgent(app.wsgi_app).get('/') #doctest: +ELLIPSIS
         Traceback (most recent call last):
             ...
         BadStatusError: GET '/' returned HTTP status '400 Bad Request'
-        >>> print TestAgent(my_app.wsgi_app).get('/?id=ratatouille') #doctest: +ELLIPSIS
+        >>> TestAgent(app.wsgi_app).get('/?id=ratatouille') #doctest: +ELLIPSIS
         Traceback (most recent call last):
             ...
         BadStatusError: GET '/' returned HTTP status '400 Bad Request'
@@ -157,12 +200,13 @@ extract_getargs.__doc__ = """\
         ... def my_app(id):
         ...     return Response(['Got id %d' % (id,)])
         ...
-        >>> print TestAgent(app).get('/')
+        >>> TestAgent(app).get('/')
         Traceback (most recent call last):
             ...
         BadStatusError: GET '/' returned HTTP status '404 Not Found'
 
-    A default argument value in the handler function will protect against this::
+    A default argument value in the handler function will protect against
+    this::
 
         >>> app = FrescoApp()
         >>> @app.route('/', GET)
@@ -189,7 +233,8 @@ extract_getargs.__doc__ = """\
         ...         ', '.join(actions)
         ...     ])
         ...
-        >>> print TestAgent(app).get('/?actions=up;actions=up;actions=and+away%21')
+        >>> print TestAgent(app).get(
+        ...     '/?actions=up;actions=up;actions=and+away%21')
         200 OK\r
         Content-Type: text/html; charset=UTF-8\r
         \r
