@@ -585,6 +585,7 @@ class Route(object):
         self.name = name
         self.predicate = predicate
         self.decorators = decorators or []
+        self.filters = []
 
         #: Default values to use for path generation
         self.routed_args_default = {}
@@ -612,6 +613,9 @@ class Route(object):
                 arg.configure(self, None)
 
         for argname, arg in self.view_kwargs.items():
+            # Allow 'Route(... x=FormArg)' shortcut
+            if isinstance(arg, type) and issubclass(arg, RouteArg):
+                arg = self.view_kwargs[argname] = arg()
             if isinstance(arg, RouteArg):
                 arg.configure(self, argname)
 
@@ -669,9 +673,23 @@ class Route(object):
         dview = self.getview()
         for d in (self.decorators or []):
             dview = d(dview)
+        if self.filters:
+            dview = self._apply_filters(dview)
         self._dview = dview
         return dview
 
+    def _apply_filters(self, view):
+        """
+        Decorate ``view`` so that the result is passed through any available
+        filters.
+        """
+        def filtered_view(*args, **kwargs):
+            result = view(*args, **kwargs)
+            for f in self.filters:
+                result = f(result)
+            return result
+        return filtered_view
+
     def bindto(self, instance):
         """\
         Return copy of the route bound to a given instance.
@@ -729,9 +747,9 @@ class Route(object):
         if func_ob is not None:
             yield func_ob
 
-    def decorate(self, *decorators):
+    def wrap(self, *decorators):
         """
-        Add a decorator into the route. Can be chained for a fluid api::
+        Wrap the view function in a decorator. Can be chained for a fluid api::
 
             Route('/user/<id:int>', GET, edituser)\
                     .decorate(require_ssl)
@@ -740,6 +758,20 @@ class Route(object):
         self.decorators.extend(decorators)
         return self
 
+    #: ``decorate`` is an alias for :meth:`~fresco.routing.Route.wrap`
+    decorate = wrap
+
+    def filter(self, *funcs):
+        """
+        Filter the output of the view function through other functions::
+
+            Route('/user/<id:int>', GET, edituser)\
+                    .decorate(require_ssl)
+                    .filter(render('user.tmpl'))
+        """
+        self.filters.extend(funcs)
+        return self
+
 
 def split_iter(pattern, string):
     """
