@@ -99,6 +99,14 @@ class TestRouteArg(object):
         with app.requestcontext('/'):
             assert 'Bad Request' in app.view().status
 
+    def test_missing_requestarg_with_conversion_returns_badrequest(self):
+        def view(x):
+            x == 0
+        app = FrescoApp()
+        app.route('/', GET, view, x=routeargs.FormArg(int))
+        with app.requestcontext('/'):
+            assert 'Bad Request' in app.view().status
+
     def test_routeargs_work_as_positional_arguments(self):
         view = Mock()
         app = FrescoApp()
