@@ -2,8 +2,8 @@
 from functools import wraps
 
 from mock import Mock
-from nose.tools import assert_raises
 from flea import TestAgent
+import pytest
 import tms
 
 from fresco import FrescoApp, GET, POST, Response
@@ -163,7 +163,8 @@ class TestRouteNames(object):
         assert 'foo' in list(r.route_keys())
 
     def test_name_cannot_contain_colon(self):
-        assert_raises(ValueError, Route, '/', GET, None, name='foo:bar')
+        with pytest.raises(ValueError):
+            Route('/', GET, None, name='foo:bar')
 
 
 class TestRouteCollection(object):
