@@ -2,12 +2,13 @@
 # Copyright (c) 2009 Oliver Cope. All rights reserved.
 # See LICENSE.txt for terms of redistribution and use.
 
+from __future__ import absolute_import
 from __future__ import unicode_literals
 from io import BytesIO
 
 from flea import TestAgent
 
-from fresco.compat import quote
+from fresco.compat import quote, ustring_type
 from fresco.util.http import parse_querystring, parse_post
 from fresco.util.wsgi import unicode_to_environ
 from fresco import FrescoApp, context, Response, POST
@@ -157,6 +158,28 @@ class TestParseFormEncodedData(object):
         r = TestAgent(app).post(data=[('f1', 'x' * 200)], check_status=False)
         assert r.response.status == "413 Request Entity Too Large"
 
+    def test_posted_data_contains_non_ascii_chars(self):
+        """
+        Verify that it raises an exception if POST data contains invalid
+        characters.
+        """
+        def view():
+            context.request.get('f1')
+
+        app = FrescoApp()
+        app.route('/', POST, view)
+
+        data = 'foo=bár'.encode('utf8')
+
+        with app.requestcontext(
+                '/',
+                REQUEST_METHOD='POST',
+                CONTENT_LENGTH=ustring_type(len(data)),
+                CONTENT_TYPE='application/x-www-form-urlencoded',
+                wsgi_input=data):
+            response = app.view()
+            assert response.status == "400 Bad Request"
+
     def test_non_utf8_data_posted(self):
 
         data = b'char=' + quote(self.char_latin1).encode('ascii')
