@@ -1,4 +1,3 @@
-from nose.tools import assert_equal
 from flea import TestAgent
 from fresco.util.wsgi import ClosingIterator, StartResponseWrapper
 
@@ -32,12 +31,12 @@ class TestClosingIterator(object):
 
         result = self.app(environ, start_response)
         result = ClosingIterator(result, count.inc)
-        assert_equal(count.value, 0)
+        assert count.value == 0
         try:
             list(result)
         finally:
             result.close()
-        assert_equal(count.value, 1)
+        assert count.value == 1
 
     def test_multiple_close_functions_called(self):
         count1 = Counter()
@@ -46,14 +45,14 @@ class TestClosingIterator(object):
 
         result = self.app(environ, start_response)
         result = ClosingIterator(result, count1.inc, count2.inc)
-        assert_equal(count1.value, 0)
-        assert_equal(count2.value, 0)
+        assert count1.value == 0
+        assert count2.value == 0
         try:
             list(result)
         finally:
             result.close()
-        assert_equal(count1.value, 1)
-        assert_equal(count2.value, 1)
+        assert count1.value == 1
+        assert count2.value == 1
 
 
 class TestStartResponseWrapper(object):
@@ -70,4 +69,4 @@ class TestStartResponseWrapper(object):
             write2(b'mat')
             return []
 
-        assert_equal(TestAgent(wsgiapp).get('/').body, 'catsatmat')
+        assert TestAgent(wsgiapp).get('/').body == 'catsatmat'
