@@ -164,22 +164,25 @@ def parse_post(environ, fp, default_charset=None, max_size=16 * KB,
     except (TypeError, ValueError, KeyError):
         raise MissingContentLength()
 
-    if ct == 'application/x-www-form-urlencoded':
-        if content_length > max_size:
-            raise TooBig("Content Length exceeds permitted size")
-        return parse_querystring(SizeLimitedInput(fp, content_length)
-                                    .read()
-                                    .decode('ASCII'), charset)
-    else:
-        if content_length > max_multipart_size:
-            raise TooBig("Content Length exceeds permitted size")
-        try:
-            boundary = ct_params['boundary']
-        except KeyError:
-            raise RequestParseError("No boundary given in multipart/form-data"
-                                    " content-type")
-        return parse_multipart(SizeLimitedInput(fp, content_length),
-                               boundary.encode('ascii'), charset, max_size)
+    try:
+        if ct == 'application/x-www-form-urlencoded':
+            if content_length > max_size:
+                raise TooBig("Content Length exceeds permitted size")
+            return parse_querystring(SizeLimitedInput(fp, content_length)
+                                        .read()
+                                        .decode('ASCII'), charset)
+        else:
+            if content_length > max_multipart_size:
+                raise TooBig("Content Length exceeds permitted size")
+            try:
+                boundary = ct_params['boundary']
+            except KeyError:
+                raise RequestParseError(
+                    "No boundary given in multipart/form-data content-type")
+            return parse_multipart(SizeLimitedInput(fp, content_length),
+                                boundary.encode('ASCII'), charset, max_size)
+    except UnicodeDecodeError:
+        raise RequestParseError("Payload contains non ascii data")
 
 
 class HTTPMessage(Message):
